==> icewm_1.4.3.0~pre-20180217.orig.tar.xz: icewm-1.4.3.0~pre-20180217/CONTRIBUTING.md <==
[icewm -- contributing file.  2017-08-03]: #

Contributing to Ice Window Manager (IceWM)
==========================================

Thank you for using [Ice Window Manager][1].  We welcome all contributions.

Bug Reports
-----------

Issues can be reported on [GitHub][2].  Please try to submit short patches or
pull requests if you can.  If you would like to perform regular maintenance
activities (e.g. if you are a maintainer of an IceWM package for a
distribution), contact me for push access.

I normally like to have the issuers of problem reports close the report once
it has been resolved.  I do not want you to think that we are being dismissive,
because I welcome all reports.

Bug reports, feedback, and suggestions pertaining to the original CVS version
can be sent to: Marko.Macek@gmx.net or icewm-user@lists.sourceforge.net

See also [BUGS][9], [TODO][7] and the sites at:

  - http://www.icewm.org/
  - http://www.sourceforge.net/projects/icewm/
  - http://icewm.sourceforge.net/


Development
-----------

If you would like to develop against this fork, the easiest way is to obtain a
[GitHub account][10], fork the [repository][1] and perform your development.
Send me a pull request when you have something stable.  If you submit regular
pull requests that get accepted, I will just give to push access to save time.


Translations
------------

You can provide translations by patching `.po` files and issuing pull requests,
or you can use the [openSUSE weblate tool][11].  There are two XDG files,
[icewm.desktop][18] and [icewm-session.desktop][19] than may need manual
translations.  If you have difficulties using the tools, just send me the updated
`.po` file or a patch to apply.


[1]: https://github.com/bbidulock/icewm/
[2]: https://github.com/bbidulock/icewm/issues/
[3]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/INSTALL
[4]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/ChangeLog
[5]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/COMPLIANCE
[6]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/NEWS
[7]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/TODO
[8]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/COPYING
[9]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/BUGS
[10]: https://github.com/
[11]: http://l10n.opensuse.org/
[12]: http://sf.net/project/showfiles.php?group_id=31&release_id=31119
[13]: http://icewm.sourceforge.net/
[14]: http://www.icewm.org/
[15]: http://www.icewm.org/FAQ/IceWM-FAQ-11.html
[16]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/doc/icewm.adoc
[17]: http://bbkeys.sourceforge.net/
[18]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/lib/icewm.desktop
[19]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/lib/icewm-session.desktop
[20]: https://github.com/bbidulock/icewm/blob/icewm-1-4-BRANCH/INSTALL-cmakebuild.md

[ vim: set ft=markdown sw=4 tw=80 nocin nosi fo+=tcqlorn: ]: #

==> icewm_3.9.0.orig.tar.xz: icewm-3.9.0/CONTRIBUTING.md <==
[icewm -- contributing file.  2017-08-03]: #

Contributing to Ice Window Manager (IceWM)
==========================================

Thank you for using [Ice Window Manager][1].  We welcome all contributions.

Bug Reports
-----------

Issues can be reported on [GitHub][2].  Please try to submit short patches or
pull requests if you can.  If you would like to perform regular maintenance
activities (e.g. if you are a maintainer of an IceWM package for a
distribution), contact me for push access.

I normally like to have the issuers of problem reports close the report once
it has been resolved.  I do not want you to think that we are being dismissive,
because I welcome all reports.

Bug reports, feedback, and suggestions pertaining to the original CVS version
can be sent to: Marko.Macek@gmx.net or icewm-user@lists.sourceforge.net

See also [BUGS][9], [TODO][7] and the sites at:

  - https://ice-wm.org/
  - https://sourceforge.net/projects/icewm/


Development
-----------

If you would like to develop against this fork, the easiest way is to obtain a
[GitHub account][10], fork the [repository][1] and perform your development.
Send me a pull request when you have something stable.  If you submit regular
pull requests that get accepted, I will just give to push access to save time.


Translations
------------

You can provide translations by patching `.po` files and issuing pull requests,
or you can use the [openSUSE weblate tool][11].  There are two XDG files,
[icewm.desktop][18] and [icewm-session.desktop][19] than may need manual
translations.  If you have difficulties using the tools, just send me the updated
`.po` file or a patch to apply.


[1]: https://github.com/bbidulock/icewm/
[2]: https://github.com/bbidulock/icewm/issues/
[3]: https://github.com/ice-wm/icewm/blob/master/INSTALL
[4]: https://github.com/ice-wm/icewm/blob/master/ChangeLog
[5]: https://github.com/ice-wm/icewm/blob/master/COMPLIANCE
[6]: https://github.com/ice-wm/icewm/blob/master/NEWS
[7]: https://github.com/ice-wm/icewm/blob/master/TODO
[8]: https://github.com/ice-wm/icewm/blob/master/COPYING
[9]: https://github.com/ice-wm/icewm/blob/master/BUGS
[10]: https://github.com/
[11]: https://l10n.opensuse.org/
[12]: https://sourceforge.net/projects/icewm/files/
[13]: https://sourceforge.net/projects/icewm/
[14]: https://ice-wm.org/
[15]: https://ice-wm.org/FAQ/
[16]: https://github.com/ice-wm/icewm/blob/master/doc/icewm.adoc
[17]: http://bbkeys.sourceforge.net/
[18]: https://github.com/ice-wm/icewm/blob/master/lib/icewm.desktop
[19]: https://github.com/ice-wm/icewm/blob/master/lib/icewm-session.desktop
[20]: https://github.com/ice-wm/icewm/blob/master/INSTALL-cmakebuild.md

[ vim: set ft=markdown sw=4 tw=80 nocin nosi fo+=tcqlorn: ]: #
